function A=randndiag(N,d,varargin)
% -- fc_amat.random.randndiag(N,d)
% -- fc_amat.random.randndiag(N,d,key,value,...)
%      Return an N-by-d-by-d amat object with normally distributed random 
%      diagonal elements (having zero mean and standard deviation one) and 
%      zeros elsewhere.
%
%      Some optional key/value pairs arguments are available with keys:
%        - 'complex', if value is true the amat object is complex and the
%                     imaginary parts of the diagonal matrices elements are 
%                     also uniformly distributed on the open interval (0, 1).
%                     (default false i.e real amat object)
%        - 'class',   value could be 'single' or 'double' (default).
%        - 'nc',      number of columns of matrices (default: d)
%        - 'k',       offset of k diagonals above or below the main diagonal; 
%                     above for positive k and below for negative k.
%        - 'mean', to set mean value (0 by default).
%        - 'sigma', to set  standard deviation value (1 by default).
%
  p = inputParser;
  p.addParamValue('complex',false,@islogical); 
  p.addParamValue('class','double',@(x) ismember(lower(x),{'single','double'}));
  p.addParamValue('nc',d,@isscalar); % number of columns
  p.addParamValue('k',0,@isscalar); % diag number
  p.addParamValue('mean',0,@isscalar); 
  p.addParamValue('sigma',1,@isscalar);
  p.parse(varargin{:});
  
  R=p.Results;
  if R.complex
    A=complex(amat(N,d,d,R.class));
    gen=@() complex(R.mean+R.sigma*randn(N,1,R.class),R.mean+R.sigma*randn(N,1,R.class));
  else
    A=amat(N,d,d,R.class);
    gen=@() R.mean+R.sigma*randn(N,1,R.class);
  end
  for i=1:min(d,R.nc)
    j=i+R.k;
    if ( j>=1 && j<=R.nc ), A(i,j)=gen(); end
  end
end
